OC.L10N.register(
    "files_external",
    {
    "External storage" : "Ārējā krātuve",
    "Personal" : "Personīgi",
    "Grant access" : "Piešķirt pieeju",
    "Access granted" : "Piešķirta pieeja",
    "Enable encryption" : "Ieslēgt šifrēšanu",
    "Saved" : "Saglabāts",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Save" : "Saglabāt",
    "None" : "Nav",
    "Port" : "Ports",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Host" : "Resursdators",
    "Location" : "Vieta",
    "ownCloud" : "ownCloud",
    "Share" : "Dalīties",
    "Name" : "Nosaukums",
    "External Storage" : "Ārējā krātuve",
    "Folder name" : "Mapes nosaukums",
    "Configuration" : "Konfigurācija",
    "Add storage" : "Pievienot krātuvi",
    "Delete" : "Dzēst"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
